pub struct Relation(/* private fields */);Expand description
A PostgreSQL relation name.
A relation is either a table or a view. Use this type when an operation accepts both tables and views (e.g., SELECT queries).
Implementations