pub struct Session {
pub application_name: Option<ApplicationName>,
pub database: Database,
pub password: Option<Password>,
pub user: User,
}Expand description
Session parameters sent during PostgreSQL connection setup.
These are independent of how the connection is established (TCP, Unix socket, etc.) and represent what the client identifies as during the startup message.
Fields
application_name: Option<ApplicationName>database: Databasepassword: Option<Password>user: UserTrait Implementations
impl Eq for Session
impl StructuralPartialEq for Session